@@ -28,7 +28,7 @@ arg_number = 0
 
 bot_token = ""
 
-class simple_discord_bot(discord.Client):
+class simple_discord_bot:
     def add_command(self, command_to_add, response, react_to=None, reaction=None, delete=False, connect_to_voicechannel=False, source_to_play=None, DM=False):
 
         command_dict[str(command_to_add)] = {
